@@ -63,6 +63,7 @@
 #include "readonlywarning.h"
 #include "../plugins/plugins.h"
 #include "plugin.h"
+#include "install_prefix.h"
 
 #include <sys/types.h>
 #include <sys/stat.h>
@@ -392,46 +393,56 @@ char * const * utility::Array::value()
 	return const_cast< char * const * >( m_vector.data() ) ;
 }
 
-bool utility::ProcessExecute( const QString& m,const QString& e,const QString& env,int uid )
+static bool _execute_process( const QString& m,const QString& exe,const QString& env,int uid )
 {
-	auto exe     = e.toLatin1() ;
-	auto m_point = m.toLatin1() ;
+	if( exe.startsWith( "/" ) && utility::pathExists( exe ) ){
 
-	if( !exe.startsWith( "/" ) ){
+		auto e = m ;
 
-		auto e = utility::Task( "which " + exe ) ;
+		e.replace( "\"","\"\"\"" ) ;
 
-		if( e.failed() ){
+		return utility::Task( exe + " \"" + m + "\"",-1,env.split( "\n" ),[ uid ](){
 
-			return false ;
-		}
+			if( uid != -1 ){
 
-		exe = e.splitOutput( '\n' ).first().toLatin1() ;
+				Q_UNUSED( setgid( uid ) ) ;
+				Q_UNUSED( setgroups( 1,reinterpret_cast< const gid_t * >( &uid ) ) ) ;
+				Q_UNUSED( setegid( uid ) ) ;
+				Q_UNUSED( setuid( uid ) ) ;				
+
+				auto id = getpwuid( uid ) ;
+
+				if( id ){
+
+					setenv( "LOGNAME",id->pw_name,1 ) ;
+					setenv( "HOME",id->pw_dir,1 ) ;
+					setenv( "USER",id->pw_name,1 ) ;
+				}
+			}
+
+		} ).success() ;
 	}else{
-		if( !utility::pathExists( exe ) ){
-
-			return false ;
-		}
+		return false ;
 	}
-
-	auto p = Process( exe.constData(),m_point.constData(),nullptr ) ;
-
-	ProcessSetOptionUser( p,uid ) ;
-
-	utility::Array array( env ) ;
-
-	ProcessSetEnvironmentalVariable( p,array.value() ) ;
-
-	ProcessStart( p ) ;
-
-	return ProcessWaitUntilFinished( &p ) == 0 ;
 }
 
 ::Task::future<bool>& utility::openPath( const QString& path,const QString& opener,const QString& env )
 {
 	return ::Task::run<bool>( [ env,path,opener ](){
 
-		return utility::ProcessExecute( path,opener,env,utility::getUID() ) == false ;
+		return _execute_process( path,opener,env,utility::getUID() ) == false ;
+	} ) ;
+}
+
+void utility::openPath( const QString& path,const QString& opener,const QString& env,QWidget * obj,const QString& title,const QString& msg )
+{
+	openPath( path,opener,env ).then( [ title,msg,obj ]( bool failed ){
+
+		if( failed && obj ){
+
+			DialogMsg m( obj ) ;
+			m.ShowUIOK( title,msg ) ;
+		}
 	} ) ;
 }
 
@@ -972,6 +983,53 @@ QString utility::resolvePath( const QString& path )
 	}
 }
 
+static QString _absolute_exe_path( const QString& exe )
+{
+	QString e = "/usr/local/bin/" + exe ;
+
+	if( utility::pathExists( e ) ){
+
+		return e ;
+	}
+
+	e = "/usr/local/sbin/" + exe ;
+
+	if( utility::pathExists( e ) ){
+
+		return e ;
+	}
+
+	e = "/usr/bin/" + exe ;
+
+	if( utility::pathExists( e ) ){
+
+		return e ;
+	}
+
+	e = "/usr/sbin/" + exe ;
+
+	if( utility::pathExists( e ) ){
+
+		return e ;
+	}
+
+	e = "/bin/" + exe ;
+
+	if( utility::pathExists( e ) ){
+
+		return e ;
+	}
+
+	e = "/sbin/" + exe ;
+
+	if( utility::pathExists( e ) ){
+
+		return e ;
+	}
+
+	return exe ;
+}
+
 QString utility::cmdArgumentValue( const QStringList& l,const QString& arg,const QString& defaulT )
 {
 	int j = l.size() ;
@@ -980,16 +1038,31 @@ QString utility::cmdArgumentValue( const QStringList& l,const QString& arg,const
 
 		if( l.at( i ) == arg ){
 
-			if( i + 1 < j ){
+			auto e = [ & ](){
 
-				return l.at( i + 1 ) ;
+				if( i + 1 < j ){
+
+					return l.at( i + 1 ) ;
+				}else{
+					return defaulT ;
+				}
+			} ;
+
+			if( arg == "-m" ){
+
+				return _absolute_exe_path( e() ) ;
 			}else{
-				return defaulT ;
+				return e() ;
 			}
 		}
 	}
 
-	return defaulT ;
+	if( defaulT == "xdg-open" ){
+
+		return _absolute_exe_path( defaulT ) ;
+	}else{
+		return defaulT ;
+	}
 }
 
 static QString _device_id_to_partition_id( const QString& id )
@@ -1625,3 +1698,10 @@ QStringList utility::directoryList( const QString& e )
 
 	return l ;
 }
+
+QIcon utility::getIcon( const QString& application )
+{
+	QIcon icon( INSTALL_PREFIX "/share/icons/hicolor/48x48/apps/" + application + ".png" ) ;
+
+	return QIcon::fromTheme( application,icon ) ;
+}
