@@ -257,10 +257,13 @@ void zuluCrypt::setupUIElements()
 {
 	m_ui->setupUi( this ) ;
 
-	this->setWindowIcon( QIcon( ":/zuluCrypt.png" ) ) ;
+	const auto& icon = utility::getIcon( "zuluCrypt" ) ;
+
+	this->setWindowIcon( icon ) ;
 
 	m_trayIcon.setParent( this ) ;
-	m_trayIcon.setIcon( QIcon( ":/zuluCrypt.png" ) ) ;
+
+	m_trayIcon.setIcon( icon ) ;
 
 	auto trayMenu = new QMenu( this ) ;
 
@@ -270,13 +273,13 @@ void zuluCrypt::setupUIElements()
 
 	m_trayIcon.setContextMenu( trayMenu ) ;
 
-	auto f = utility::getWindowDimensions( "zuluCrypt" ) ;
+	const auto f = utility::getWindowDimensions( "zuluCrypt" ) ;
 
-	auto e = f.data() ;
+	const auto e = f.data() ;
 
 	this->window()->setGeometry( *( e + 0 ),*( e + 1 ),*( e + 2 ),*( e + 3 ) ) ;
 
-	auto table = m_ui->tableWidget ;
+	const auto table = m_ui->tableWidget ;
 
 	table->setColumnWidth( 0,*( e + 4 ) ) ;
 	table->setColumnWidth( 1,*( e + 5 ) ) ;
@@ -583,7 +586,7 @@ void zuluCrypt::dropEvent( QDropEvent * e )
 {
 	for( const auto& it : e->mimeData()->urls() ){
 
-		const QString& e = it.path() ;
+		const auto& e = it.path() ;
 
 		if( utility::pathPointsToAFile( e ) ){
 
@@ -793,28 +796,18 @@ void zuluCrypt::openFolder()
 
 void zuluCrypt::openFolder( const QString& path )
 {
-	utility::openPath( path,m_openPath,m_env ).then( [ this ]( bool failed ){
+	auto x = tr( "WARNING!" ) ;
+	auto y = tr( "Could not open mount point because \"%1\" tool does not appear to be working correctly").arg( m_openPath ) ;
 
-		if( failed ){
-
-			DialogMsg msg( this ) ;
-
-			msg.ShowUIOK( tr( "WARNING!" ),tr( "Could not open mount point because \"%1\" tool does not appear to be working correctly").arg( m_openPath ) ) ;
-		}
-	} ) ;
+	utility::openPath( path,m_openPath,m_env,this,x,y ) ;
 }
 
 void zuluCrypt::openpdf()
 {
-	utility::openPath( PDF_PATH,m_openPath ).then( [ this ]( bool failed ){
+	auto x = tr( "WARNING!" ) ;
+	auto y = tr( "Failed to open zuluCrypt.pdf,make sure your system can open pdf files using \"%1\" tool and try again" ).arg( m_openPath ) ;
 
-		if( failed ){
-
-			DialogMsg msg( this ) ;
-
-			msg.ShowUIOK( tr( "WARNING!" ),tr( "Failed to open zuluCrypt.pdf,make sure your system can open pdf files using \"%1\" tool and try again" ).arg( m_openPath ) ) ;
-		}
-	} ) ;
+	utility::openPath( PDF_PATH,m_openPath,m_env,this,x,y ) ;
 }
 
 void zuluCrypt::itemClicked( QTableWidgetItem * it )
@@ -923,8 +916,10 @@ void zuluCrypt::closeStatusErrorMessage( int st )
 		case 5 :UIMessage( tr( "ERROR!" ),tr( "Close failed, volume is unmounted but could not close mapper,advice to close it manually" ) ) ;	break ;
 		case 6 :UIMessage( tr( "ERROR!" ),tr( "Close failed, could not resolve full path of device\n" ) ) ;               			break ;
 		case 7 :UIMessage( tr( "ERROR!" ),tr( "Close failed, shared mount point appear to be busy\n" ) ) ;					break ;
-		case 8 :UIMessage( tr( "ERROR!" ),tr( "Close failed, shared mount point appear to belong to a different user\n" ) ) ;			break ;
-		case 9 :UIMessage( tr( "ERROR!" ),tr( "Close failed, shared mount point appear to be in an ambiguous state,advice to unmount manually" )) ;break ;
+		case 8 :UIMessage( tr( "ERROR!" ),tr( "Close failed, shared mount point appear to belong to a different user or multiple mount points detected\n" ) ) ;			break ;
+		case 9 :UIMessage( tr( "ERROR!" ),tr( "Close failed, shared mount point appear to be in an ambiguous state,advice to unmount manually" ) ) ;break ;
+		case 10:UIMessage( tr( "ERROR!" ),tr( "Close failed, multiple mount points for the volume detected" ) ) ;                               break ;
+
 		case 110:UIMessage( tr( "ERROR!" ),tr( "Close failed, could not find any partition with the presented UUID" ) ) ;			break ;
 		default:UIMessage( tr( "ERROR!" ),tr( "Unrecognized error with status number %1 encountered" ).arg( st ) ) ;
 	}
@@ -1091,15 +1086,13 @@ zuluCrypt::~zuluCrypt()
 
 	const auto& r = this->window()->geometry() ;
 
-	using list = std::initializer_list<int> ;
-
-	utility::setWindowDimensions( "zuluCrypt",list{ r.x(),
-							r.y(),
-							r.width(),
-							r.height(),
-							q->columnWidth( 0 ),
-							q->columnWidth( 1 ),
-							q->columnWidth( 2 ) } ) ;
+	utility::setWindowDimensions( "zuluCrypt",{ r.x(),
+						    r.y(),
+						    r.width(),
+						    r.height(),
+						    q->columnWidth( 0 ),
+						    q->columnWidth( 1 ),
+						    q->columnWidth( 2 ) } ) ;
 
 	delete m_ui ;
 }
