@@ -62,7 +62,7 @@ keyDialog::keyDialog( QWidget * parent,QTableWidget * table,const volumeEntryPro
 	m_table = table ;
 	m_path = e.volumeName() ;
 	m_working = false ;
-	m_volumeIsEncFs = e.fileSystem() == "encfs" ;
+	m_encryptedFolder = e.fileSystem() == "cryptfs" ;
 
 	decltype( tr( "" ) ) msg ;
 
@@ -128,7 +128,7 @@ keyDialog::keyDialog( QWidget * parent,QTableWidget * table,const volumeEntryPro
 	auto _add_action = [ & ]( const QString& e ){
 
 		ac = m_menu_1->addAction( e ) ;
-		ac ->setEnabled( !m_volumeIsEncFs ) ;
+		ac ->setEnabled( !m_encryptedFolder ) ;
 	} ;
 
 	_add_action( tr( "Set File System Options" ) ) ;
@@ -141,7 +141,7 @@ keyDialog::keyDialog( QWidget * parent,QTableWidget * table,const volumeEntryPro
 	m_ui->cbKeyType->addItem( tr( "Key+KeyFile" ) ) ;
 	m_ui->cbKeyType->addItem( tr( "Plugin" ) ) ;
 
-	if( m_volumeIsEncFs ){
+	if( m_encryptedFolder ){
 
 		m_ui->checkBoxShareMountPoint->setEnabled( false ) ;
 	}else{
@@ -279,7 +279,7 @@ void keyDialog::enableAll()
 	m_ui->pbkeyOption->setEnabled( true ) ;
 	m_ui->checkBoxOpenReadOnly->setEnabled( true ) ;
 
-	if( !m_volumeIsEncFs ){
+	if( !m_encryptedFolder ){
 
 		m_ui->checkBoxShareMountPoint->setEnabled( true ) ;
 	}
@@ -332,7 +332,7 @@ void keyDialog::pbkeyOption()
 void keyDialog::Plugin()
 {
 	utility::createPlugInMenu( m_menu,tr( INTERNAL_WALLET ),
-				   tr( GNOME_WALLET ),tr( KWALLET ),!m_volumeIsEncFs ) ;
+				   tr( GNOME_WALLET ),tr( KWALLET ),!m_encryptedFolder ) ;
 
 	m_menu->setFont( this->font() ) ;
 
@@ -422,48 +422,78 @@ void keyDialog::pbOpen()
 	}
 }
 
-void keyDialog::encfsMount()
+void keyDialog::encryptedFolderMount()
 {
 	auto m = utility::mountPath( utility::mountPathPostFix( m_ui->lineEditMountPoint->text() ) ) ;
 
 	auto ro = m_ui->checkBoxOpenReadOnly->isChecked() ;
 
-	if( zuluMountTask::encfsMount( m_path,m,m_key,ro ).await() ){
+	DialogMsg msg( this ) ;
 
-		/*
-		 * TODO: Not suspending for a while causes a process that open the mount point
-		 * to exit prematurely with "QProcess: Destroyed while process is still running." warning.
-		 * look into why this happens.
-		 *
-		 */
-		this->hide() ;
+	switch( zuluMountTask::encryptedFolderMount( m_path,m,m_key,ro ).await().state ){
 
-		utility::Task::suspend( 2 ) ;
+	using ev = zuluMountTask::encryptedVolume ;
+
+	case ev::status::success :
 
 		m_success( m ) ;
 
-		this->HideUI() ;
-	}else{
-		DialogMsg msg( this ) ;
+		return this->HideUI() ;
 
-		msg.ShowUIOK( tr( "ERROR" ),tr( "Failed to unlock an encfs volume.\nWrong password or not an encfs volume" ) ) ;
+	case ev::status::cryfs :
 
-		if( m_ui->cbKeyType->currentIndex() == keyDialog::Key ){
+		msg.ShowUIOK( tr( "ERROR" ),tr( "Failed to unlock a cryfs volume.\nWrong password entered" ) ) ;
+		break;
 
-			m_ui->lineEditKey->clear() ;
-		}
+	case ev::status::encfs :
 
-		m_ui->lineEditKey->setFocus() ;
+		msg.ShowUIOK( tr( "ERROR" ),tr( "Failed to unlock an encfs volume.\nWrong password entered" ) ) ;
+		break;
 
-		return this->enableAll() ;
+	case ev::status::cryfsNotFound :
+
+		msg.ShowUIOK( tr( "ERROR" ),tr( "Failed to unlock a cryfs volume.\ncryfs executable could not be found" ) ) ;
+		break;
+
+	case ev::status::encfsNotFound :
+
+		msg.ShowUIOK( tr( "ERROR" ),tr( "Failed to unlock an encfs volume.\nencfs executable could not be found" ) ) ;
+		break;
+
+	case ev::status::failedToCreateMountPoint :
+
+		msg.ShowUIOK( tr( "ERROR" ),tr( "Failed to create mount point" ) ) ;
+		break;
+
+	case ev::status::unknown :
+
+		msg.ShowUIOK( tr( "ERROR" ),tr( "Failed to unlock the volume.\nNot supported volume encountered" ) ) ;
+		break;
+
+	case ev::status::backendFail :
+
+		msg.ShowUIOK( tr( "ERROR" ),tr( "Failed to unlock the volume.\nBackend not responding" ) ) ;
+		break;
+	default:
+		msg.ShowUIOK( tr( "ERROR" ),tr( "Failed to unlock the volume.\nNot supported volume encountered" ) ) ;
+		break;
 	}
+
+	if( m_ui->cbKeyType->currentIndex() == keyDialog::Key ){
+
+		m_ui->lineEditKey->clear() ;
+	}
+
+	m_ui->lineEditKey->setFocus() ;
+
+	this->enableAll() ;
 }
 
 void keyDialog::openVolume()
 {
 	auto keyType = m_ui->cbKeyType->currentIndex() ;
 
-	if( m_volumeIsEncFs ){
+	if( m_encryptedFolder ){
 
 		if( keyType == keyDialog::Key || keyType == keyDialog::keyKeyFile ){
 
@@ -484,7 +514,7 @@ void keyDialog::openVolume()
 			 */
 		}
 
-		return this->encfsMount() ;
+		return this->encryptedFolderMount() ;
 	}
 
 	if( m_ui->lineEditKey->text().isEmpty() ){
